SECRET_KEY = 'SECRET_KEY'
SQLALCHEMY_DATABASE_URI = 'sqlite:///../paano.db'
CSRF_ENABLED = True
GOOGLE_LOGIN_CLIENT_ID = 'CLIENT_ID'
GOOGLE_LOGIN_CLIENT_SECRET = 'CLIENT_SECRET'
GOOGLE_LOGIN_REDIRECT_URI = 'http://localhost:5000/oauth2callback'
ALLOWED_USERS = ('GOOGLE_USER_ID',)
