{% extends "base.html" %}

{% block content %}
<h2><a href="{{ category.url() }}">{{ category.title }}</a> &rsaquo; {{ question.title }}</h2>
{% if current_user.is_authenticated() %}
<p><a class="edit" href="{{ question.url(edit=1) }}">Edit question</a></p>
{% endif %}
{{ m.html(question.content) | safe }}
{% endblock %}