{% extends "base.html" %}

{% block content %}
<h2>{{ category.title }}</h2>
{% if current_user.is_authenticated() %}
<p><a class="edit" href="{{ category.url(edit=1) }}">Edit category</a></p>
{% endif %}
<ul class="questions">
{% for question in questions %}
    <li>
        <a href="{{ question.url() }}">{{ question.title }}</a>
    </li>
{% endfor %}
</ul>
{% endblock %}